==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Carregamento médio",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Informações de memória não disponíveis",
    "Total" : "Total",
    "Current usage" : "Uso atual:",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Links" : "Links",
    "Federated sent" : "Envio federado",
    "Federated received" : "Recebimento federado",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última 1 hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "Monitoring" : "Monitoramento",
    "CPU load" : "Carga da CPU",
    "Memory usage" : "Uso de memória",
    "Active users" : "Usuários ativos",
    "Shares" : "Compartilhamentos",
    "Storage" : "Armazenamento",
    "Users:" : "Usuários:",
    "Files:" : "Arquivos:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory Limit:" : "Limite de memória:",
    "Max Execution Time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "Size:" : "Tamanho:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "You can connect an external monitoring tool by using this end point: " : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto: ",
    "Server info" : "Informação do servidor",
    "You can connect a external monitoring tool by using this end point: " : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto final:"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/pt_BR.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Carregamento médio",
    "Last minute" : "Último minuto",
    "Memory info not available" : "Informações de memória não disponíveis",
    "Total" : "Total",
    "Current usage" : "Uso atual:",
    "Users" : "Usuários",
    "Groups" : "Grupos",
    "Links" : "Links",
    "Federated sent" : "Envio federado",
    "Federated received" : "Recebimento federado",
    "Last 24 hours" : "Últimas 24 horas",
    "Last 1 hour" : "Última 1 hora",
    "Last 5 mins" : "Últimos 5 minutos",
    "Monitoring" : "Monitoramento",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece informações úteis do servidor, como carga de CPU, uso de RAM, uso do disco, número de usuários, etc.",
    "CPU load" : "Carga da CPU",
    "Memory usage" : "Uso de memória",
    "Active users" : "Usuários ativos",
    "Shares" : "Compartilhamentos",
    "Storage" : "Armazenamento",
    "Users:" : "Usuários:",
    "Files:" : "Arquivos:",
    "PHP" : "PHP",
    "Version:" : "Versão:",
    "Memory Limit:" : "Limite de memória:",
    "Max Execution Time:" : "Tempo máximo de execução:",
    "Upload max size:" : "Tamanho máximo para envio:",
    "Database" : "Banco de Dados",
    "Type:" : "Tipo:",
    "Size:" : "Tamanho:",
    "External monitoring tool" : "Ferramenta de monitoramento externo",
    "You can connect an external monitoring tool by using this end point: " : "Você pode conectar uma ferramenta de monitoramento externa usando este ponto: "
},
"nplurals=2; plural=(n > 1);");
